==> ParaView-v5.1.2.tar.gz: ParaView-v5.1.2/Examples/CustomApplications/ParticlesViewer/ParticlesViewerDisplayPolicy.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    ParticlesViewerDisplayPolicy.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "ParticlesViewerDisplayPolicy.h"

#include "pqApplicationCore.h"
#include "pqObjectBuilder.h"
#include "pqSMAdaptor.h"
#include "pqDataRepresentation.h"
#include "vtkSMProxy.h"

//-----------------------------------------------------------------------------
pqDataRepresentation* ParticlesViewerDisplayPolicy::newRepresentation(
  pqOutputPort* port, pqView* view) const
{
  pqDataRepresentation* repr = pqApplicationCore::instance()->getObjectBuilder()->
    createDataRepresentation(port, view);
  if (repr)
    {
    pqSMAdaptor::setEnumerationProperty(
      repr->getProxy()->GetProperty("Representation"),
      "Point Sprite");
    repr->getProxy()->UpdateVTKObjects();
    }
  return repr;
}

==> ParaView-v5.2.0.tar.gz: ParaView-v5.2.0/Examples/CustomApplications/ParticlesViewer/ParticlesViewerDisplayPolicy.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    ParticlesViewerDisplayPolicy.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "ParticlesViewerDisplayPolicy.h"

#include "pqApplicationCore.h"
#include "pqDataRepresentation.h"
#include "pqObjectBuilder.h"
#include "pqSMAdaptor.h"
#include "vtkSMProxy.h"

//-----------------------------------------------------------------------------
pqDataRepresentation* ParticlesViewerDisplayPolicy::newRepresentation(
  pqOutputPort* port, pqView* view) const
{
  pqDataRepresentation* repr =
    pqApplicationCore::instance()->getObjectBuilder()->createDataRepresentation(port, view);
  if (repr)
  {
    pqSMAdaptor::setEnumerationProperty(
      repr->getProxy()->GetProperty("Representation"), "Point Sprite");
    repr->getProxy()->UpdateVTKObjects();
  }
  return repr;
}
